@@ -555,26 +555,6 @@ class TestTrainer(unittest.TestCase):
                 with self.assertRaises(ValueError):
                     self.boring_trainer._set_randomness(seed)
 
-    def test_clear_ram(self):
-        """GIVEN a Trainer class correctly initialized and trained
-        WHEN clear_ram() is called
-        THEN test the RAM is cleared
-        """
-
-        trainer = Trainer(
-            self.simple_config,
-            self.simple_model,
-            train_dataset=self.train_dataset,
-        )
-        
-        history = trainer.train(100)
-
-        ram_before_clearing = psutil.virtual_memory().percent
-
-        trainer.clear_ram()
-        ram_after_clearing = psutil.virtual_memory().percent
-
-        self.assertGreaterEqual(ram_before_clearing, ram_after_clearing)
 
     def test_summary_model_no_initialized(self):
         """GIVEN a Trainer class
