@@ -39,7 +39,7 @@ class TrainingModel(BaseModel, extra=Extra.allow):
     optimizer: Union[
         constr(strict=True), conlist(item_type=Dict, min_items=1, max_items=2)
     ] = "Adam"
-    optimizer_params: Optional[Dict[str, Any]] = None  # obsolete
+    optimizer_params: Optional[Dict[str, Any]] = None  
     epochs: PositiveInt = 1
     batch_size: PositiveInt = 1  # if format is numpy
     loss: Union[constr(strict=True), Dict[str, Any]]
