@@ -453,6 +453,9 @@ class Trainer:
                         opt_pars["learning_rate"] = scheduler(**v)
                         return optimizer(**opt_pars)
         elif isinstance(opt, str):
+
+            opt_pars = self.config.optimizer_params if self.config.optimizer_params is not None else dict()
+
             optimizer = getattr(
                 tf.keras.optimizers, f"{self.config.optimizer}", default_value
             )
@@ -480,7 +483,7 @@ class Trainer:
             if loss != default_value:
                 return loss(**loss_params)
             else:
-                return self._load_custom_module(loss_config, loss_params)
+                return self._load_custom_module(loss_name, loss_params)
 
     def _get_callbacks(self) -> List[tf.keras.callbacks.Callback]:
         """Get the callbacks from the config file"""
@@ -685,7 +688,6 @@ class Trainer:
         self._validate_config_file()
 
         self._callbacks = self._get_callbacks()
-        #self._input_shape = self._get_input_shape()
         self._sample_weight_mode = self._get_sample_weight_mode()
 
         self._trainer_initialized = True
